==> kvision-react-4.5.1.jar: kvision-kvision-react-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kotlin-wrappers-kotlin-react-jsLegacy', 'kotlin-wrappers-kotlin-react-dom-jsLegacy', 'kvision-js-legacy', 'react', 'jquery', 'jquery-kotlin-jsLegacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kotlin-wrappers-kotlin-react-jsLegacy'), require('kotlin-wrappers-kotlin-react-dom-jsLegacy'), require('kvision-js-legacy'), require('react'), require('jquery'), require('jquery-kotlin-jsLegacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['kotlin-wrappers-kotlin-react-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kotlin-wrappers-kotlin-react-jsLegacy' was not found. Please, check whether 'kotlin-wrappers-kotlin-react-jsLegacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['kotlin-wrappers-kotlin-react-dom-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kotlin-wrappers-kotlin-react-dom-jsLegacy' was not found. Please, check whether 'kotlin-wrappers-kotlin-react-dom-jsLegacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['kvision-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kvision-js-legacy' was not found. Please, check whether 'kvision-js-legacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof react === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'react' was not found. Please, check whether 'react' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof jQuery === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'jquery' was not found. Please, check whether 'jquery' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['jquery-kotlin-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'jquery-kotlin-jsLegacy' was not found. Please, check whether 'jquery-kotlin-jsLegacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }root['kvision-kvision-react-js-legacy'] = factory(typeof this['kvision-kvision-react-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-react-js-legacy'], kotlin, this['kotlin-wrappers-kotlin-react-jsLegacy'], this['kotlin-wrappers-kotlin-react-dom-jsLegacy'], this['kvision-js-legacy'], react, jQuery, this['jquery-kotlin-jsLegacy']);
  }
}(this, function (_, Kotlin, $module$kotlin_wrappers_kotlin_react_jsLegacy, $module$kotlin_wrappers_kotlin_react_dom_jsLegacy, $module$kvision_js_legacy, $module$react, $module$jquery, $module$jquery_kotlin_jsLegacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var Kind_OBJECT = Kotlin.Kind.OBJECT;
  var Unit = Kotlin.kotlin.Unit;
  var throwCCE = Kotlin.throwCCE;
  var child = $module$kotlin_wrappers_kotlin_react_jsLegacy.react.child_9r8yuv$;
  var render = $module$kotlin_wrappers_kotlin_react_dom_jsLegacy.react.dom.render_2955dm$;
  var Widget = $module$kvision_js_legacy.io.kvision.core.Widget;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var ObservableState = $module$kvision_js_legacy.io.kvision.state.ObservableState;
  var get_set = $module$kvision_js_legacy.io.kvision.utils.get_set_5cw0du$;
  var emptySet = Kotlin.kotlin.collections.emptySet_287e2$;
  var ArrayList_init = Kotlin.kotlin.collections.ArrayList_init_287e2$;
  var functionalComponent = $module$kotlin_wrappers_kotlin_react_jsLegacy.react.functionalComponent_7g4vsr$;
  var createRef = $module$react.createRef;
  var ensureNotNull = Kotlin.ensureNotNull;
  var ContainerType = $module$kvision_js_legacy.io.kvision.panel.ContainerType;
  var Root_init = $module$kvision_js_legacy.io.kvision.panel.Root_init_39w7fw$;
  var useEffectWithCleanup = $module$kotlin_wrappers_kotlin_react_jsLegacy.react.useEffectWithCleanup_y10uuc$;
  var rawUseState = $module$kotlin_wrappers_kotlin_react_jsLegacy.$$importsForInline$$.react.useState;
  var Any = Object;
  var RStateDelegate_init = $module$kotlin_wrappers_kotlin_react_jsLegacy.react.RStateDelegate;
  var attributesMapOf = $module$kotlin_wrappers_kotlin_react_dom_jsLegacy.$$importsForInline$$['kotlinx-html-js'].kotlinx.html.attributesMapOf_jyasbz$;
  var DIV_init = $module$kotlin_wrappers_kotlin_react_dom_jsLegacy.$$importsForInline$$['kotlinx-html-js'].kotlinx.html.DIV;
  var RDOMBuilder_init = $module$kotlin_wrappers_kotlin_react_dom_jsLegacy.react.dom.RDOMBuilder;
  React.prototype = Object.create(Widget.prototype);
  React.prototype.constructor = React;
  var kVManagerReactInit;
  function KVManagerReact() {
    KVManagerReact_instance = this;
    this.reactDom_8be2vx$ = require('react-dom');
  }
  KVManagerReact.prototype.init_8be2vx$ = function () {
  };
  KVManagerReact.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'KVManagerReact',
    interfaces: []
  };
  var KVManagerReact_instance = null;
  function KVManagerReact_getInstance() {
    if (KVManagerReact_instance === null) {
      new KVManagerReact();
    }return KVManagerReact_instance;
  }
  function React(state, classes, builder) {
    if (classes === void 0) {
      classes = emptySet();
    }Widget.call(this, classes);
    this.builder_0 = builder;
    this.observers_0 = ArrayList_init();
    this.state_utm9xm$_0 = state;
    this.refreshFunction_0 = null;
  }
  Object.defineProperty(React.prototype, 'state', {
    configurable: true,
    get: function () {
      return this.state_utm9xm$_0;
    },
    set: function (value) {
      var tmp$;
      this.state_utm9xm$_0 = value;
      (tmp$ = this.refreshFunction_0) != null ? tmp$(value) : null;
      var tmp$_0;
      tmp$_0 = this.observers_0.iterator();
      while (tmp$_0.hasNext()) {
        var element = tmp$_0.next();
        element(this.state);
      }
    }
  });
  function React$afterInsert$lambda$lambda$lambda(this$React) {
    return function () {
      return this$React.state;
    };
  }
  function React$afterInsert$lambda$lambda$lambda_0(this$React, closure$refresh) {
    return function (changeState) {
      this$React.state = changeState(this$React.state);
      closure$refresh(this$React.state);
      return Unit;
    };
  }
  function React$afterInsert$lambda$lambda(this$React) {
    return function ($receiver, refresh) {
      this$React.refreshFunction_0 = refresh;
      this$React.builder_0($receiver, React$afterInsert$lambda$lambda$lambda(this$React), React$afterInsert$lambda$lambda$lambda_0(this$React, refresh));
      return Unit;
    };
  }
  function React$afterInsert$lambda(this$React) {
    return function ($receiver) {
      child($receiver, reactWrapper(React$afterInsert$lambda$lambda(this$React)));
      return Unit;
    };
  }
  React.prototype.afterInsert_cmtal8$ = function (node) {
    var tmp$;
    render(Kotlin.isType(tmp$ = node.elm, HTMLElement) ? tmp$ : throwCCE(), void 0, React$afterInsert$lambda(this));
  };
  React.prototype.afterDestroy = function () {
    var tmp$, tmp$_0;
    if ((tmp$_0 = (tmp$ = this.vnode) != null ? tmp$.elm : null) != null) {
      KVManagerReact_getInstance().reactDom_8be2vx$.unmountComponentAtNode(tmp$_0);
    }};
  React.prototype.getState = function () {
    return this.state;
  };
  function React$subscribe$lambda(this$React, closure$observer) {
    return function () {
      var $receiver = this$React.observers_0;
      var element = closure$observer;
      $receiver.remove_11rb$(element);
      return Unit;
    };
  }
  React.prototype.subscribe_qlkmfe$ = function (observer) {
    this.observers_0.add_11rb$(observer);
    observer(this.state);
    return React$subscribe$lambda(this, observer);
  };
  React.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'React',
    interfaces: [ObservableState, Widget]
  };
  function React_init(classes, builder, $this) {
    if (classes === void 0) {
      classes = emptySet();
    }$this = $this || Object.create(React.prototype);
    React.call($this, {}, classes, builder);
    return $this;
  }
  function react($receiver, state, classes, className, builder) {
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    var react = new React(state, classes != null ? classes : get_set(className), builder);
    $receiver.add_87eobz$(react);
    return react;
  }
  function reactBind$lambda(closure$react) {
    return function (it) {
      closure$react.state = it;
      return Unit;
    };
  }
  function reactBind($receiver, state, classes, className, builder) {
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    var react = new React(state.getState(), classes != null ? classes : get_set(className), builder);
    react.addBeforeDisposeHook_o14v8n$(state.subscribe_qlkmfe$(reactBind$lambda(react)));
    $receiver.add_87eobz$(react);
    return react;
  }
  function react$lambda(closure$builder) {
    return function ($receiver, f, f_0) {
      closure$builder($receiver);
    };
  }
  function react_0($receiver, classes, className, builder) {
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    var fullBuilder = react$lambda(builder);
    var react = React_init(classes != null ? classes : get_set(className), fullBuilder);
    $receiver.add_87eobz$(react);
    return react;
  }
  function div$lambda(closure$classes) {
    return function (it) {
      return new DIV_init(attributesMapOf('class', closure$classes), it);
    };
  }
  function reactWrapper$lambda$lambda() {
    return {};
  }
  function reactWrapper$lambda(closure$builder) {
    return function ($receiver, it) {
      var tmp$, tmp$_0;
      var tmp$_1 = rawUseState(reactWrapper$lambda$lambda);
      var state = tmp$_1[0];
      var setState = tmp$_1[1];
      var state_0 = new RStateDelegate_init((tmp$ = state) == null || Kotlin.isType(tmp$, Any) ? tmp$ : throwCCE(), typeof (tmp$_0 = setState) === 'function' ? tmp$_0 : throwCCE());
      closure$builder($receiver, state_0.component2());
      return Unit;
    };
  }
  function reactWrapper(builder) {
    return functionalComponent(void 0, reactWrapper$lambda(builder));
  }
  function kvisionWrapper$lambda$lambda$lambda(closure$root, closure$el) {
    return function () {
      var tmp$, tmp$_0;
      (tmp$ = closure$root.v) != null ? (tmp$.dispose(), Unit) : null;
      if ((tmp$_0 = closure$el.v) != null) {
        $module$jquery(tmp$_0).remove();
      }return Unit;
    };
  }
  function kvisionWrapper$lambda$lambda(closure$elRef, closure$builder) {
    return function () {
      var tmp$;
      var root = {v: null};
      var el = {v: null};
      if ((tmp$ = closure$elRef.current) != null) {
        var closure$builder_0 = closure$builder;
        var tmp$_0;
        el.v = Kotlin.isType(tmp$_0 = document.createElement('div'), HTMLElement) ? tmp$_0 : throwCCE();
        tmp$.appendChild(ensureNotNull(el.v));
        root.v = Root_init(ensureNotNull(el.v), ContainerType.NONE, false, closure$builder_0);
      }return kvisionWrapper$lambda$lambda$lambda(root, el);
    };
  }
  function kvisionWrapper$lambda(closure$builder) {
    return function ($receiver, it) {
      var elRef = createRef();
      useEffectWithCleanup(void 0, kvisionWrapper$lambda$lambda(elRef, closure$builder));
      var $receiver_0 = new RDOMBuilder_init(div$lambda(null));
      $receiver_0.ref = elRef;
      $receiver.child_52psg1$($receiver_0.create());
      return Unit;
    };
  }
  function kvisionWrapper(builder) {
    return functionalComponent(void 0, kvisionWrapper$lambda(builder));
  }
  function kv($receiver, builder) {
    return child($receiver, kvisionWrapper(builder));
  }
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  Object.defineProperty(package$kvision, 'kVManagerReactInit_8be2vx$', {
    get: function () {
      return kVManagerReactInit;
    }
  });
  Object.defineProperty(package$kvision, 'KVManagerReact', {
    get: KVManagerReact_getInstance
  });
  var package$react = package$kvision.react || (package$kvision.react = {});
  package$react.React_init_rz8ak6$ = React_init;
  package$react.React = React;
  package$react.react_1ujf1j$ = react;
  package$react.reactBind_wx8llz$ = reactBind;
  package$react.react_allzie$ = react_0;
  $$importsForInline$$['kotlin-wrappers-kotlin-react-jsLegacy'] = $module$kotlin_wrappers_kotlin_react_jsLegacy;
  package$react.reactWrapper_llc0jw$ = reactWrapper;
  $$importsForInline$$['jquery-kotlin-jsLegacy'] = $module$jquery_kotlin_jsLegacy;
  $$importsForInline$$['kotlin-wrappers-kotlin-react-dom-jsLegacy'] = $module$kotlin_wrappers_kotlin_react_dom_jsLegacy;
  package$react.kvisionWrapper_t5svx8$ = kvisionWrapper;
  package$react.kv_i7m45p$ = kv;
  kVManagerReactInit = KVManagerReact_getInstance().init_8be2vx$();
  Kotlin.defineModule('kvision-kvision-react-js-legacy', _);
  return _;
}));

==> kvision-react-4.6.0.jar: kvision-kvision-react-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kotlin-wrappers-kotlin-react-js-legacy', 'kotlin-wrappers-kotlin-react-dom-js-legacy', 'kvision-js-legacy', 'react', 'jquery', 'jquery-kotlin-jsLegacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kotlin-wrappers-kotlin-react-js-legacy'), require('kotlin-wrappers-kotlin-react-dom-js-legacy'), require('kvision-js-legacy'), require('react'), require('jquery'), require('jquery-kotlin-jsLegacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['kotlin-wrappers-kotlin-react-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kotlin-wrappers-kotlin-react-js-legacy' was not found. Please, check whether 'kotlin-wrappers-kotlin-react-js-legacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['kotlin-wrappers-kotlin-react-dom-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kotlin-wrappers-kotlin-react-dom-js-legacy' was not found. Please, check whether 'kotlin-wrappers-kotlin-react-dom-js-legacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['kvision-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'kvision-js-legacy' was not found. Please, check whether 'kvision-js-legacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof react === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'react' was not found. Please, check whether 'react' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof jQuery === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'jquery' was not found. Please, check whether 'jquery' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }if (typeof this['jquery-kotlin-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-react-js-legacy'. Its dependency 'jquery-kotlin-jsLegacy' was not found. Please, check whether 'jquery-kotlin-jsLegacy' is loaded prior to 'kvision-kvision-react-js-legacy'.");
    }root['kvision-kvision-react-js-legacy'] = factory(typeof this['kvision-kvision-react-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-react-js-legacy'], kotlin, this['kotlin-wrappers-kotlin-react-js-legacy'], this['kotlin-wrappers-kotlin-react-dom-js-legacy'], this['kvision-js-legacy'], react, jQuery, this['jquery-kotlin-jsLegacy']);
  }
}(this, function (_, Kotlin, $module$kotlin_wrappers_kotlin_react_js_legacy, $module$kotlin_wrappers_kotlin_react_dom_js_legacy, $module$kvision_js_legacy, $module$react, $module$jquery, $module$jquery_kotlin_jsLegacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var Kind_OBJECT = Kotlin.Kind.OBJECT;
  var Unit = Kotlin.kotlin.Unit;
  var throwCCE = Kotlin.throwCCE;
  var child = $module$kotlin_wrappers_kotlin_react_js_legacy.react.child_9r8yuv$;
  var render = $module$kotlin_wrappers_kotlin_react_dom_js_legacy.react.dom.render_2955dm$;
  var Widget = $module$kvision_js_legacy.io.kvision.core.Widget;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var ObservableState = $module$kvision_js_legacy.io.kvision.state.ObservableState;
  var get_set = $module$kvision_js_legacy.io.kvision.utils.get_set_5cw0du$;
  var emptySet = Kotlin.kotlin.collections.emptySet_287e2$;
  var ArrayList_init = Kotlin.kotlin.collections.ArrayList_init_287e2$;
  var functionalComponent = $module$kotlin_wrappers_kotlin_react_js_legacy.react.functionalComponent_7g4vsr$;
  var createRef = $module$react.createRef;
  var ensureNotNull = Kotlin.ensureNotNull;
  var ContainerType = $module$kvision_js_legacy.io.kvision.panel.ContainerType;
  var Root_init = $module$kvision_js_legacy.io.kvision.panel.Root_init_39w7fw$;
  var useEffectWithCleanup = $module$kotlin_wrappers_kotlin_react_js_legacy.react.useEffectWithCleanup_y10uuc$;
  var rawUseState = $module$kotlin_wrappers_kotlin_react_js_legacy.$$importsForInline$$.react.useState;
  var Any = Object;
  var RStateDelegate_init = $module$kotlin_wrappers_kotlin_react_js_legacy.react.RStateDelegate;
  var attributesMapOf = $module$kotlin_wrappers_kotlin_react_dom_js_legacy.$$importsForInline$$['kotlinx-html-js'].kotlinx.html.attributesMapOf_jyasbz$;
  var DIV_init = $module$kotlin_wrappers_kotlin_react_dom_js_legacy.$$importsForInline$$['kotlinx-html-js'].kotlinx.html.DIV;
  var RDOMBuilder_init = $module$kotlin_wrappers_kotlin_react_dom_js_legacy.react.dom.RDOMBuilder;
  React.prototype = Object.create(Widget.prototype);
  React.prototype.constructor = React;
  var kVManagerReactInit;
  function KVManagerReact() {
    KVManagerReact_instance = this;
    this.reactDom_8be2vx$ = require('react-dom');
  }
  KVManagerReact.prototype.init_8be2vx$ = function () {
  };
  KVManagerReact.$metadata$ = {
    kind: Kind_OBJECT,
    simpleName: 'KVManagerReact',
    interfaces: []
  };
  var KVManagerReact_instance = null;
  function KVManagerReact_getInstance() {
    if (KVManagerReact_instance === null) {
      new KVManagerReact();
    }return KVManagerReact_instance;
  }
  function React(state, classes, builder) {
    if (classes === void 0) {
      classes = emptySet();
    }Widget.call(this, classes);
    this.builder_0 = builder;
    this.observers_0 = ArrayList_init();
    this.state_utm9xm$_0 = state;
    this.refreshFunction_0 = null;
  }
  Object.defineProperty(React.prototype, 'state', {
    configurable: true,
    get: function () {
      return this.state_utm9xm$_0;
    },
    set: function (value) {
      var tmp$;
      this.state_utm9xm$_0 = value;
      (tmp$ = this.refreshFunction_0) != null ? tmp$(value) : null;
      var tmp$_0;
      tmp$_0 = this.observers_0.iterator();
      while (tmp$_0.hasNext()) {
        var element = tmp$_0.next();
        element(this.state);
      }
    }
  });
  function React$afterInsert$lambda$lambda$lambda(this$React) {
    return function () {
      return this$React.state;
    };
  }
  function React$afterInsert$lambda$lambda$lambda_0(this$React, closure$refresh) {
    return function (changeState) {
      this$React.state = changeState(this$React.state);
      closure$refresh(this$React.state);
      return Unit;
    };
  }
  function React$afterInsert$lambda$lambda(this$React) {
    return function ($receiver, refresh) {
      this$React.refreshFunction_0 = refresh;
      this$React.builder_0($receiver, React$afterInsert$lambda$lambda$lambda(this$React), React$afterInsert$lambda$lambda$lambda_0(this$React, refresh));
      return Unit;
    };
  }
  function React$afterInsert$lambda(this$React) {
    return function ($receiver) {
      child($receiver, reactWrapper(React$afterInsert$lambda$lambda(this$React)));
      return Unit;
    };
  }
  React.prototype.afterInsert_cmtal8$ = function (node) {
    var tmp$;
    render(Kotlin.isType(tmp$ = node.elm, HTMLElement) ? tmp$ : throwCCE(), void 0, React$afterInsert$lambda(this));
  };
  React.prototype.afterDestroy = function () {
    var tmp$, tmp$_0;
    if ((tmp$_0 = (tmp$ = this.vnode) != null ? tmp$.elm : null) != null) {
      KVManagerReact_getInstance().reactDom_8be2vx$.unmountComponentAtNode(tmp$_0);
    }};
  React.prototype.getState = function () {
    return this.state;
  };
  function React$subscribe$lambda(this$React, closure$observer) {
    return function () {
      var $receiver = this$React.observers_0;
      var element = closure$observer;
      $receiver.remove_11rb$(element);
      return Unit;
    };
  }
  React.prototype.subscribe_qlkmfe$ = function (observer) {
    this.observers_0.add_11rb$(observer);
    observer(this.state);
    return React$subscribe$lambda(this, observer);
  };
  React.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'React',
    interfaces: [ObservableState, Widget]
  };
  function React_init(classes, builder, $this) {
    if (classes === void 0) {
      classes = emptySet();
    }$this = $this || Object.create(React.prototype);
    React.call($this, {}, classes, builder);
    return $this;
  }
  function react($receiver, state, classes, className, builder) {
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    var react = new React(state, classes != null ? classes : get_set(className), builder);
    $receiver.add_87eobz$(react);
    return react;
  }
  function reactBind$lambda(closure$react) {
    return function (it) {
      closure$react.state = it;
      return Unit;
    };
  }
  function reactBind($receiver, state, classes, className, builder) {
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    var react = new React(state.getState(), classes != null ? classes : get_set(className), builder);
    react.addBeforeDisposeHook_o14v8n$(state.subscribe_qlkmfe$(reactBind$lambda(react)));
    $receiver.add_87eobz$(react);
    return react;
  }
  function react$lambda(closure$builder) {
    return function ($receiver, f, f_0) {
      closure$builder($receiver);
    };
  }
  function react_0($receiver, classes, className, builder) {
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    var fullBuilder = react$lambda(builder);
    var react = React_init(classes != null ? classes : get_set(className), fullBuilder);
    $receiver.add_87eobz$(react);
    return react;
  }
  function div$lambda(closure$classes) {
    return function (it) {
      return new DIV_init(attributesMapOf('class', closure$classes), it);
    };
  }
  function reactWrapper$lambda$lambda() {
    return {};
  }
  function reactWrapper$lambda(closure$builder) {
    return function ($receiver, it) {
      var tmp$, tmp$_0;
      var tmp$_1 = rawUseState(reactWrapper$lambda$lambda);
      var state = tmp$_1[0];
      var setState = tmp$_1[1];
      var state_0 = new RStateDelegate_init((tmp$ = state) == null || Kotlin.isType(tmp$, Any) ? tmp$ : throwCCE(), typeof (tmp$_0 = setState) === 'function' ? tmp$_0 : throwCCE());
      closure$builder($receiver, state_0.component2());
      return Unit;
    };
  }
  function reactWrapper(builder) {
    return functionalComponent(void 0, reactWrapper$lambda(builder));
  }
  function kvisionWrapper$lambda$lambda$lambda(closure$root, closure$el) {
    return function () {
      var tmp$, tmp$_0;
      (tmp$ = closure$root.v) != null ? (tmp$.dispose(), Unit) : null;
      if ((tmp$_0 = closure$el.v) != null) {
        $module$jquery(tmp$_0).remove();
      }return Unit;
    };
  }
  function kvisionWrapper$lambda$lambda(closure$elRef, closure$builder) {
    return function () {
      var tmp$;
      var root = {v: null};
      var el = {v: null};
      if ((tmp$ = closure$elRef.current) != null) {
        var closure$builder_0 = closure$builder;
        var tmp$_0;
        el.v = Kotlin.isType(tmp$_0 = document.createElement('div'), HTMLElement) ? tmp$_0 : throwCCE();
        tmp$.appendChild(ensureNotNull(el.v));
        root.v = Root_init(ensureNotNull(el.v), ContainerType.NONE, false, closure$builder_0);
      }return kvisionWrapper$lambda$lambda$lambda(root, el);
    };
  }
  function kvisionWrapper$lambda(closure$builder) {
    return function ($receiver, it) {
      var elRef = createRef();
      useEffectWithCleanup(void 0, kvisionWrapper$lambda$lambda(elRef, closure$builder));
      var $receiver_0 = new RDOMBuilder_init(div$lambda(null));
      $receiver_0.ref = elRef;
      $receiver.child_52psg1$($receiver_0.create());
      return Unit;
    };
  }
  function kvisionWrapper(builder) {
    return functionalComponent(void 0, kvisionWrapper$lambda(builder));
  }
  function kv($receiver, builder) {
    return child($receiver, kvisionWrapper(builder));
  }
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  Object.defineProperty(package$kvision, 'kVManagerReactInit_8be2vx$', {
    get: function () {
      return kVManagerReactInit;
    }
  });
  Object.defineProperty(package$kvision, 'KVManagerReact', {
    get: KVManagerReact_getInstance
  });
  var package$react = package$kvision.react || (package$kvision.react = {});
  package$react.React_init_rz8ak6$ = React_init;
  package$react.React = React;
  package$react.react_1ujf1j$ = react;
  package$react.reactBind_wx8llz$ = reactBind;
  package$react.react_allzie$ = react_0;
  $$importsForInline$$['kotlin-wrappers-kotlin-react-js-legacy'] = $module$kotlin_wrappers_kotlin_react_js_legacy;
  package$react.reactWrapper_llc0jw$ = reactWrapper;
  $$importsForInline$$['jquery-kotlin-jsLegacy'] = $module$jquery_kotlin_jsLegacy;
  $$importsForInline$$['kotlin-wrappers-kotlin-react-dom-js-legacy'] = $module$kotlin_wrappers_kotlin_react_dom_js_legacy;
  package$react.kvisionWrapper_t5svx8$ = kvisionWrapper;
  package$react.kv_i7m45p$ = kv;
  kVManagerReactInit = KVManagerReact_getInstance().init_8be2vx$();
  Kotlin.defineModule('kvision-kvision-react-js-legacy', _);
  return _;
}));
